@@ -499,38 +499,39 @@ class DataTransformerForm(BaseInlineFormSet):
                 files=form.files if form.is_bound else None
             )
 
-            form.nested_constants_form = DataConstantsTransformerInlineFormset(
-                instance=form.instance,
-                data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None
-            )
 
-            form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-                instance=form.instance,
-                data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None
-            )
+        form.nested_constants_form = DataConstantsTransformerInlineFormset(
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None
+        )
 
-            form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-                instance=form.instance,
-                data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None
-            )
+        form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None
+        )
+
+        form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None
+        )
 
     def as_p(self):
         # super(self.__class__,self).as_p()
         forms = ' '
         for form in self:
             forms.join(form.as_p())
-            if form.nested_data_transformer_form is not None:
+            if hasattr(form, 'nested_data_transformer_form') and form.nested_data_transformer_form is not None:
                 forms.join(form.nested_data_transformer_form.as_p())
-            if form.nested_constants_form is not None:
+            if hasattr(form, 'nested_constants_form') and form.nested_constants_form is not None:
 
                 forms.join(form.nested_constants_form.as_p())
-            if form.nested_hardware_outputs_form is not None:
+            if hasattr(form, 'nested_hardware_outputs_form') and form.nested_hardware_outputs_form is not None:
 
                 forms.join(form.nested_hardware_outputs_form.as_p())
-            if form.nested_hardware_stats_form is not None:
+            if hasattr(form, 'nested_hardware_stats_form') and form.nested_hardware_stats_form is not None:
 
                 forms.join(form.nested_hardware_stats_form.as_p())
 
