@@ -392,7 +392,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
 
         datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,formset=DataTransformerForm,
                                                    fk_name='parent',
-                                                   extra=1, exclude=['updated_at', 'created_at'])
+                                                   extra=1, exclude=['updated_at', 'created_at'], form=DataTransform)
 
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
